#
# Libdax
#
# Copyright © 2016 Oracle corp.  All rights reserved.
# The Universal Permissive License (UPL), Version 1.0
#
# Subject to the condition set forth below, permission is hereby granted to any person obtaining a copy of this
# software, associated documentation and/or data (collectively the "Software"), free of charge and under any and
# all copyright rights in the Software, and any and all patent rights owned or freely licensable by each licensor
# hereunder covering either (i) the unmodified Software as contributed to or provided by such licensor, or
# (ii) the Larger Works (as defined below), to deal in both
#
# (a) the Software, and
# (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if one is included with the Software
# (each a “Larger Work” to which the Software is contributed by such licensors),
#
# without restriction, including without limitation the rights to copy, create derivative works of, display,
# perform, and distribute the Software and make, use, sell, offer for sale, import, export, have made, and have
# sold the Software and the Larger Work(s), and to sublicense the foregoing rights on either these or other terms.
#
# This license is subject to the following condition:
# The above copyright notice and either this complete permission notice or at a minimum a reference to the UPL must
# be included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
# THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
# CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
# IN THE SOFTWARE.
#

#
# Spec file for libDAX
#
Summary: DAX Co-processor library
Name: libdax
%define subversion 24
#
# update makefiles if you change the version and/or release numbers
Version: 0.1
Release: %{subversion}%{?dist}
License: UPL
Vendor: Oracle America
Group: Development/Libraries
ExclusiveArch: sparc64
Source: %{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: systemtap-sdt-devel

%description
Oracle DAX library

%package devel
Summary: Development files for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains header files for developing
applications that use the functions provided by %{name}.

%prep
%setup

%build
make RELEASE=."%{subversion}"

%install
rm -rf %{buildroot}
make install DESTDIR="%{buildroot}" RELEASE=."%{subversion}"

%clean
make clean
rm -fr %{buildroot}

%post
/sbin/ldconfig
(/sbin/modprobe dax; exit 0) 2>/dev/null

%postun
/sbin/ldconfig

%files
%defattr(-,root,root)
%{_libdir}/*.so.*
%{_sbindir}/daxperf
%{_datadir}/*
%config /etc/udev/rules.d/10-dax.rules
%config /etc/sysconfig/modules/dax.modules

%files devel
%defattr(-,root,root)
%{_includedir}/dax.h
%{_includedir}/dax_query.h
%{_libdir}/*.so

%changelog
* Tue Apr 25 2017 Rob Gardner <rob.gardner@oracle.com> - 0.1-24
- (Re)Add debug option to produce debuginfo rpm

* Fri Apr 7 2017 Rob Gardner <rob.gardner@oracle.com> - 0.1-23
- Adds sub-page memory allocator; No rmmod on uninstall.

* Thu Mar 30 2017 Rob Gardner <rob.gardner@oracle.com> - 0.1-22
- New driver API, backward compatible with old

* Wed Oct 26 2016 Rob Gardner <rob.gardner@oracle.com> - 0.1-21
- Add automatic driver loading when system boots
- Correct definition of OUTPUT_BLKS
- Change to finite timeout in mwait loop
- specfile now exports rpm version to makefiles

* Tue Oct 11 2016 Rob Gardner <rob.gardner@oracle.com> - 0.1-20
- Round down internal dynp allocations to 4mb
- Debug output formatting

* Thu Sep 22 2016 Rob Gardner <rob.gardner@oracle.com> - 0.1-19
- Return proper error code when page overflow is detected
- New test programs for 64k and 4m synthetic pages

* Sun Aug 21 2016 Rob Gardner <rob.gardner@oracle.com> - 0.1-18
- Add daxperf command, which reports dax performance counters
- Add perf counter ioctl defs to sys_dax.h
- Move address info reporting into libdax
- Add several new test programs to test for page overflows
- Add dax_zero, which uses query/extract to zero memory

* Wed Jul 27 2016 Rob Gardner <rob.gardner@oracle.com> - 0.1-17
- Fix error logging levels and add page overflow reporting

* Wed Jul 06 2016 Rob Gardner <rob.gardner@oracle.com> - 0.1-16
- Improved resilience against MAP errors
- Updated DAX driver version to 2, and use dax_alloc for internal output bit vectors
- Logging of page sizes for all input and output addresses
- New test program for dax_alloc

* Fri Jun 10 2016 Rob Gardner <rob.gardner@oracle.com> - 0.1-15
- Changes to support DAX memory allocator
- Some debug features
- Universal Permissive License (UPL)

* Mon Mar 21 2016 Rob Gardner <rob.gardner@oracle.com> - 0.1-14
- Changes to support a DAX driver with only ioctl interface
- Changes to support DAX memory allocator
- Some debug features

* Sat Aug 22 2015 Rob Gardner <rob.gardner@oracle.com> - 0.1-13
- Link libdax_query against libdax so that applications that
- use libdax_query do not need to use -ldax 

* Mon Jun 22 2015 Rob Gardner <rob.gardner@oracle.com> - 0.1-12
- Libdax refresh from on12 10-Jun-2015
- SONAMEs properly set and .so files only installed by devel rpm

* Sun Mar 08 2015 Rob Gardner <rob.gardner@oracle.com> - 0.1-11
- Driver API change to enable return of unmapped address errors

* Thu Feb 05 2015 Rob Gardner <rob.gardner@oracle.com> - 0.1-9
- Bug fixes for new compiler and additional debug and logging options

* Mon Jan 12 2015 Rob Gardner <rob.gardner@oracle.com> - 0.1-8
- Performance release; Optimization, huge pages, ccb fast path is default

* Mon Nov 24 2014 Rob Gardner <rob.gardner@oracle.com> - 0.1-7
- Merge specfiles so there is just one for package and devel

* Tue Nov 11 2014 Rob Gardner <rob.gardner@oracle.com> - 0.1-6
- New source base entirely, cloned from on12 tahoe 10-Nov-2014,
- requires updated dax driver

* Mon Nov 3 2014 Rob Gardner <rob.gardner@oracle.com> - 0.1-5
- Remove dax.h, and move it to the devel rpm along
- with the other necessary include files.

* Fri Oct 17 2014 Rob Gardner <rob.gardner@oracle.com> - 0.1-4
- Make libraries executable so that debuginfo gets produced

* Wed Oct 15 2014 Rob Gardner <rob.gardner@oracle.com> - 0.1-3
- Major API overhaul

* Fri Sep 5 2014 Rob Gardner <rob.gardner@oracle.com> - 0.1-2
- Changes to dax.h so program source does not have to
- explicitly include stdint.h; Also remove lint stuff.

* Thu Sep 4 2014 Rob Gardner <rob.gardner@oracle.com> - 0.1-1
- Made first rpm of libdax

